==> maGUI_2.3.tar.gz: maGUI/R/class.R <==
clas<-function(h,...){
	f<-function(h,...){
		x<<-svalue(h$obj)
		}
		try(({
		dat2Affy.m<-dat2Affy.m;datAgOne2.m<-datAgOne2.m;datAgTwo2.m<-datAgTwo2.m;datIllBA2.m2<-datIllBA2.m2;
		lumi_NQ.m<-lumi_NQ.m;data.matrix_Nimblegen2.m<-data.matrix_Nimblegen2.m;
		data.matrixNorm.m<-data.matrixNorm.m;data.matrix_onlineNorm.m<-data.matrix_onlineNorm.m;
		use.dat2Affy.m<-use.dat2Affy.m;use.datAgOne2.m<-use.datAgOne2.m;use.datAgTwo2.m<-use.datAgTwo2.m;
		use.datIllBA2.m2<-use.datIllBA2.m2;use.lumi_NQ.m<-use.lumi_NQ.m;
		use.data.matrix_Nimblegen2.m<-use.data.matrix_Nimblegen2.m;
		use.data.matrixNorm.m<-use.data.matrixNorm.m;use.data.matrix_onlineNorm.m<-use.data.matrix_onlineNorm.m;
		dat2Affy.f<-dat2Affy.f;datAgOne2.f<-datAgOne2.f;datAgTwo2.f<-datAgTwo2.f;
		datIllBA2.f<-datIllBA2.f;lumi_NQ.f<-lumi_NQ.f;data.matrix_Nimblegen2.f<-data.matrix_Nimblegen2.f;
		data.matrixNorm.f<-data.matrixNorm.f;data.matrix_onlineNorm.f<-data.matrix_onlineNorm.f;
		design_Affy<-design_Affy;design_Ag1<-design_Ag1;design_Ag2<-design_Ag2;
		design_Il_B<-design_Il_B;design_Il_L<-design_Il_L;design_N<-design_N;design_S<-design_S;design_O<-design_O;
		DE_Affy<-DE_Affy;DE_Ag1<-DE_Ag1;DE_Ag2<-DE_Ag2;DE_Il_B<-DE_Il_B;DE_Il_L<-DE_Il_L;
		DE_N<-DE_N;DE_S<-DE_S;DE_O<-DE_O;l<-l;tree<-tree;
			}),silent=TRUE)

	platforms=NULL;
	aa=0;bb=0;cc=0;dd=0;ee=0;ff=0;gg=0;hh=0;
	try(({
		if(exists("dat2Affy.f"))aa=length(dat2Affy.f)
		if(exists("datAgOne2.f"))bb=length(datAgOne2.f)
		if(exists("datAgTwo2.f"))cc=length(datAgTwo2.f)
		if(exists("datIllBA2.f"))dd=length(datIllBA2.f)
		if(exists("lumi_NQ.f"))ee=length(lumi_NQ.f)
		if(exists("data.matrix_Nimblegen2.f"))ff=length(data.matrix_Nimblegen2.f)
		if(exists("data.matrixNorm.f"))gg=length(data.matrixNorm.f)
		if(exists("data.matrix_onlineNorm.f"))hh=length(data.matrix_onlineNorm.f)
		}),silent=TRUE)
	if(aa!=0)platforms=c(platforms,"Affymetrix")
	if(bb!=0)platforms=c(platforms,"Agilent_OneColor")
	if(cc!=0)platforms=c(platforms,"Agilent_TwoColor")
	if(dd!=0)platforms=c(platforms,"Illumina_Beadarray")
	if(ee!=0)platforms=c(platforms,"Illumina_Lumi")
	if(ff!=0)platforms=c(platforms,"Nimblegen")
	if(gg!=0)platforms=c(platforms,"Series_Matrix")
	if(hh!=0)platforms=c(platforms,"Online_Data")

	use_DE_Affy=NULL;use_DE_Ag1=NULL;use_DE_Ag2=NULL;use_DE_Il_B=NULL;use_DE_Il_L=NULL;
	use_DE_N=NULL;use_DE_S=NULL;use_DE_O=NULL;heatcol=NULL;
	Clas_Affy=NULL;	Clas_Ag1=NULL;Clas_Ag2=NULL;Clas_Il_B=NULL;Clas_Il_L=NULL;Clas_N=NULL;Clas_S=NULL;Clas_O=NULL;
	samp_Affy=NULL;samp_Ag1=NULL;samp_Ag2=NULL;samp_Il_B=NULL;samp_Il_L=NULL;samp_N=NULL;samp_S=NULL;samp_O=NULL;

	rm(use_DE_Affy,use_DE_Ag1,use_DE_Ag2,use_DE_Il_B,use_DE_Il_L,
	use_DE_N,use_DE_S,use_DE_O,heatcol,
	Clas_Affy,Clas_Ag1,Clas_Ag2,Clas_Il_B,Clas_Il_L,Clas_N,Clas_S,Clas_O,
	samp_Affy,samp_Ag1,samp_Ag2,samp_Il_B,samp_Il_L,samp_N,samp_S,samp_O)

	x=NULL
	z=NULL
	w_dge<-gwindow("Select your data",width=260,height=280,visible=FALSE,horizontal=FALSE)
	gp_dge<-ggroup(container=w_dge,horizontal=FALSE)
	cbg_dge<-gcheckboxgroup(platforms,container=gp_dge,handler=f)
	svalue(cbg_dge,index=FALSE)<-1:8
	
	gp2_dge<-ggroup(container=gp_dge,width=30,height=15,horizontal=TRUE)
	addSpring(gp2_dge)
	y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
		dispose(w_dge)
	},container=gp2_dge,anchor=c(1,-1))
	y2<-gbutton("OK",border=TRUE,handler=function(h,...){
		if(length(x)!=0){
			svalue(sb)<-"				Please wait while Classification.."
			heatcol<<-colorRampPalette(c("Green","Red"))(32) ##############
			if(length(which(x=="Affymetrix"))!=0){
				er_x<-try(use_DE_Affy<<-DE_Affy,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_Affy)<<-as.character(DE_Affy)
					use_DE_Affy<<-DE_Affy
				}
				err_x<-try(Clas_Affy<<-use.dat2Affy.m[rownames(use_DE_Affy),samp_Affy],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_Affy<<-use.dat2Affy.m[rownames(use_DE_Affy),]
				}
				heatmap(Clas_Affy,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_Affy)!=0){
					visible(g1_1)<-FALSE
					l$Affymetrix$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
			if(length(which(x=="Agilent_OneColor"))!=0){
				er_x<-try(use_DE_Ag1<<-DE_Ag1,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_Ag1)<<-as.character(DE_Ag1)
					use_DE_Ag1<<-DE_Ag1
				}
				err_x<-try(Clas_Ag1<<-use.datAgOne2.m[rownames(use_DE_Ag1),samp_Ag1],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_Ag1<<-use.datAgOne2.m[rownames(use_DE_Ag1),]
				}
				heatmap(Clas_Ag1,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_Ag1)!=0){
					visible(g1_1)<-FALSE
					l$Agilent_OneColor$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
			if(length(which(x=="Agilent_TwoColor"))!=0){
				er_x<-try(use_DE_Ag2<<-DE_Ag2,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_Ag2)<<-as.character(DE_Ag2)
					use_DE_Ag2<<-DE_Ag2
				}
				err_x<-try(Clas_Ag2<<-use.datAgTwo2.m[rownames(use_DE_Ag2),samp_Ag2],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_Ag2<<-use.datAgTwo2.m[rownames(use_DE_Ag2),]
				}
				heatmap(Clas_Ag2,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_Ag2)!=0){
					visible(g1_1)<-FALSE
					l$Agilent_TwoColor$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
			if(length(which(x=="Illumina_Beadarray"))!=0){
				er_x<-try(use_DE_Il_B<<-DE_Il_B,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_Il_B)<<-as.character(DE_Il_B)
					use_DE_Il_B<<-DE_Il_B
				}
				err_x<-try(Clas_Il_B<<-use.datIllBA2.m2[rownames(use_DE_Il_B),samp_Il_B],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_Il_B<<-use.datIllBA2.m2[rownames(use_DE_Il_B),]
				}
				heatmap(Clas_Il_B,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_Il_B)!=0){
					visible(g1_1)<-FALSE
					l$Illumina_Beadarray$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
			if(length(which(x=="Illumina_Lumi"))!=0){
				er_x<-try(use_DE_Il_L<<-DE_Il_L,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_Il_L)<<-as.character(DE_Il_L)
					use_DE_Il_L<<-DE_Il_L
				}
				err_x<-try(Clas_Il_L<<-use.lumi_NQ.m[rownames(use_DE_Il_L),samp_Il_L],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_Il_L<<-use.lumi_NQ.m[rownames(use_DE_Il_L),]
				}
				heatmap(Clas_Il_L,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_Il_L)!=0){
					visible(g1_1)<-FALSE
					l$Illumina_Lumi$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
			if(length(which(x=="Nimblegen"))!=0){
				er_x<-try(use_DE_N<<-DE_N,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_N)<<-as.character(DE_N)
					use_DE_N<<-DE_N
				}
				err_x<-try(Clas_N<<-use.data.matrix_Nimblegen2.m[rownames(use_DE_N),samp_N],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_N<<-use.data.matrix_Nimblegen2.m[rownames(use_DE_N),]
				}
				heatmap(Clas_N,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_N)!=0){
					visible(g1_1)<-FALSE
					l$Nimblegen$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
  			}
			if(length(which(x=="Series_Matrix"))!=0){
				er_x<-try(use_DE_S<<-DE_S,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_S)<<-as.character(DE_S)
					use_DE_S<<-DE_S
				}
				err_x<-try(Clas_S<<-use.data.matrixNorm.m[use_DE_S$ID,samp_S],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_S<<-use.data.matrixNorm.m[rownames(use_DE_S),]
				}
				heatmap(Clas_S,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_S)!=0){
					visible(g1_1)<-FALSE
					l$Series_Matrix$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
			if(length(which(x=="Online_Data"))!=0){
				er_x<-try(use_DE_O<<-DE_O,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_O)<<-as.character(DE_O)
					use_DE_O<<-DE_O
				}
				err_x<-try(Clas_O<<-use.data.matrix_onlineNorm.m[rownames(use_DE_O),samp_O],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_O<<-use.data.matrix_onlineNorm.m[use_DE_O$ID,]
				}
				heatmap(Clas_O,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_O)!=0){
					visible(g1_1)<-FALSE
					l$Online_Data$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
		svalue(sb)<-"Done"
		dispose(w_dge)
		}else{
			gmessage("Plz select the data for Classification","Select Data")
		}
		svalue(sb)<-"Done"
		dispose(w_dge)
	},container=gp2_dge,anchor=c(1,-1))
	visible(w_dge)<-TRUE
}

==> maGUI_2.4.tar.gz: maGUI/R/class.R <==
clas<-function(h,...){
	f<-function(h,...){
		x<<-svalue(h$obj)
		}
		try(({
		dat2Affy.m<-dat2Affy.m;datAgOne2.m<-datAgOne2.m;datAgTwo2.m<-datAgTwo2.m;datIllBA2.m2<-datIllBA2.m2;
		lumi_NQ.m<-lumi_NQ.m;data.matrix_Nimblegen2.m<-data.matrix_Nimblegen2.m;
		data.matrixNorm.m<-data.matrixNorm.m;data.matrix_onlineNorm.m<-data.matrix_onlineNorm.m;
		use.dat2Affy.m<-use.dat2Affy.m;use.datAgOne2.m<-use.datAgOne2.m;use.datAgTwo2.m<-use.datAgTwo2.m;
		use.datIllBA2.m2<-use.datIllBA2.m2;use.lumi_NQ.m<-use.lumi_NQ.m;
		use.data.matrix_Nimblegen2.m<-use.data.matrix_Nimblegen2.m;
		use.data.matrixNorm.m<-use.data.matrixNorm.m;use.data.matrix_onlineNorm.m<-use.data.matrix_onlineNorm.m;
		dat2Affy.f<-dat2Affy.f;datAgOne2.f<-datAgOne2.f;datAgTwo2.f<-datAgTwo2.f;
		datIllBA2.f<-datIllBA2.f;lumi_NQ.f<-lumi_NQ.f;data.matrix_Nimblegen2.f<-data.matrix_Nimblegen2.f;
		data.matrixNorm.f<-data.matrixNorm.f;data.matrix_onlineNorm.f<-data.matrix_onlineNorm.f;
		design_Affy<-design_Affy;design_Ag1<-design_Ag1;design_Ag2<-design_Ag2;
		design_Il_B<-design_Il_B;design_Il_L<-design_Il_L;design_N<-design_N;design_S<-design_S;design_O<-design_O;
		DE_Affy<-DE_Affy;DE_Ag1<-DE_Ag1;DE_Ag2<-DE_Ag2;DE_Il_B<-DE_Il_B;DE_Il_L<-DE_Il_L;
		DE_N<-DE_N;DE_S<-DE_S;DE_O<-DE_O;l<-l;tree<-tree;
			}),silent=TRUE)

	platforms=NULL;
	aa=0;bb=0;cc=0;dd=0;ee=0;ff=0;gg=0;hh=0;
	try(({
		if(exists("dat2Affy.f"))aa=length(dat2Affy.f)
		if(exists("datAgOne2.f"))bb=length(datAgOne2.f)
		if(exists("datAgTwo2.f"))cc=length(datAgTwo2.f)
		if(exists("datIllBA2.f"))dd=length(datIllBA2.f)
		if(exists("lumi_NQ.f"))ee=length(lumi_NQ.f)
		if(exists("data.matrix_Nimblegen2.f"))ff=length(data.matrix_Nimblegen2.f)
		if(exists("data.matrixNorm.f"))gg=length(data.matrixNorm.f)
		if(exists("data.matrix_onlineNorm.f"))hh=length(data.matrix_onlineNorm.f)
		}),silent=TRUE)
	if(aa!=0)platforms=c(platforms,"Affymetrix")
	if(bb!=0)platforms=c(platforms,"Agilent_OneColor")
	if(cc!=0)platforms=c(platforms,"Agilent_TwoColor")
	if(dd!=0)platforms=c(platforms,"Illumina_Beadarray")
	if(ee!=0)platforms=c(platforms,"Illumina_Lumi")
	if(ff!=0)platforms=c(platforms,"Nimblegen")
	if(gg!=0)platforms=c(platforms,"Series_Matrix")
	if(hh!=0)platforms=c(platforms,"Online_Data")

	use_DE_Affy=NULL;use_DE_Ag1=NULL;use_DE_Ag2=NULL;use_DE_Il_B=NULL;use_DE_Il_L=NULL;
	use_DE_N=NULL;use_DE_S=NULL;use_DE_O=NULL;heatcol=NULL;
	Clas_Affy=NULL;	Clas_Ag1=NULL;Clas_Ag2=NULL;Clas_Il_B=NULL;Clas_Il_L=NULL;Clas_N=NULL;Clas_S=NULL;Clas_O=NULL;
	samp_Affy=NULL;samp_Ag1=NULL;samp_Ag2=NULL;samp_Il_B=NULL;samp_Il_L=NULL;samp_N=NULL;samp_S=NULL;samp_O=NULL;

	rm(use_DE_Affy,use_DE_Ag1,use_DE_Ag2,use_DE_Il_B,use_DE_Il_L,
	use_DE_N,use_DE_S,use_DE_O,heatcol,
	Clas_Affy,Clas_Ag1,Clas_Ag2,Clas_Il_B,Clas_Il_L,Clas_N,Clas_S,Clas_O,
	samp_Affy,samp_Ag1,samp_Ag2,samp_Il_B,samp_Il_L,samp_N,samp_S,samp_O)

	x=NULL
	z=NULL
	w_dge<-gwindow("Select your data",width=260,height=280,visible=FALSE,fill="y")
	gp_dge<-ggroup(container=w_dge,fill="y")
	cbg_dge<-gcheckboxgroup(platforms,container=gp_dge,handler=f)
	svalue(cbg_dge,index=FALSE)<-1:8
	
	gp2_dge<-ggroup(container=gp_dge,width=30,height=15,fill="x")
	addSpring(gp2_dge)
	y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
		dispose(w_dge)
	},container=gp2_dge,anchor=c(1,-1))
	y2<-gbutton("OK",border=TRUE,handler=function(h,...){
		if(length(x)!=0){
			svalue(sb)<-"				Please wait while Classification.."
			heatcol<<-colorRampPalette(c("Green","Red"))(32) ##############
			if(length(which(x=="Affymetrix"))!=0){
				er_x<-try(use_DE_Affy<<-DE_Affy,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_Affy)<<-as.character(DE_Affy)
					use_DE_Affy<<-DE_Affy
				}
				err_x<-try(Clas_Affy<<-use.dat2Affy.m[rownames(use_DE_Affy),samp_Affy],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_Affy<<-use.dat2Affy.m[rownames(use_DE_Affy),]
				}
				heatmap(Clas_Affy,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_Affy)!=0){
					visible(g1_1)<-FALSE
					l$Affymetrix$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
			if(length(which(x=="Agilent_OneColor"))!=0){
				er_x<-try(use_DE_Ag1<<-DE_Ag1,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_Ag1)<<-as.character(DE_Ag1)
					use_DE_Ag1<<-DE_Ag1
				}
				err_x<-try(Clas_Ag1<<-use.datAgOne2.m[rownames(use_DE_Ag1),samp_Ag1],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_Ag1<<-use.datAgOne2.m[rownames(use_DE_Ag1),]
				}
				heatmap(Clas_Ag1,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_Ag1)!=0){
					visible(g1_1)<-FALSE
					l$Agilent_OneColor$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
			if(length(which(x=="Agilent_TwoColor"))!=0){
				er_x<-try(use_DE_Ag2<<-DE_Ag2,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_Ag2)<<-as.character(DE_Ag2)
					use_DE_Ag2<<-DE_Ag2
				}
				err_x<-try(Clas_Ag2<<-use.datAgTwo2.m[rownames(use_DE_Ag2),samp_Ag2],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_Ag2<<-use.datAgTwo2.m[rownames(use_DE_Ag2),]
				}
				heatmap(Clas_Ag2,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_Ag2)!=0){
					visible(g1_1)<-FALSE
					l$Agilent_TwoColor$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
			if(length(which(x=="Illumina_Beadarray"))!=0){
				er_x<-try(use_DE_Il_B<<-DE_Il_B,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_Il_B)<<-as.character(DE_Il_B)
					use_DE_Il_B<<-DE_Il_B
				}
				err_x<-try(Clas_Il_B<<-use.datIllBA2.m2[rownames(use_DE_Il_B),samp_Il_B],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_Il_B<<-use.datIllBA2.m2[rownames(use_DE_Il_B),]
				}
				heatmap(Clas_Il_B,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_Il_B)!=0){
					visible(g1_1)<-FALSE
					l$Illumina_Beadarray$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
			if(length(which(x=="Illumina_Lumi"))!=0){
				er_x<-try(use_DE_Il_L<<-DE_Il_L,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_Il_L)<<-as.character(DE_Il_L)
					use_DE_Il_L<<-DE_Il_L
				}
				err_x<-try(Clas_Il_L<<-use.lumi_NQ.m[rownames(use_DE_Il_L),samp_Il_L],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_Il_L<<-use.lumi_NQ.m[rownames(use_DE_Il_L),]
				}
				heatmap(Clas_Il_L,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_Il_L)!=0){
					visible(g1_1)<-FALSE
					l$Illumina_Lumi$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
			if(length(which(x=="Nimblegen"))!=0){
				er_x<-try(use_DE_N<<-DE_N,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_N)<<-as.character(DE_N)
					use_DE_N<<-DE_N
				}
				err_x<-try(Clas_N<<-use.data.matrix_Nimblegen2.m[rownames(use_DE_N),samp_N],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_N<<-use.data.matrix_Nimblegen2.m[rownames(use_DE_N),]
				}
				heatmap(Clas_N,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_N)!=0){
					visible(g1_1)<-FALSE
					l$Nimblegen$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
  			}
			if(length(which(x=="Series_Matrix"))!=0){
				er_x<-try(use_DE_S<<-DE_S,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_S)<<-as.character(DE_S)
					use_DE_S<<-DE_S
				}
				err_x<-try(Clas_S<<-use.data.matrixNorm.m[use_DE_S$ID,samp_S],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_S<<-use.data.matrixNorm.m[rownames(use_DE_S),]
				}
				heatmap(Clas_S,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_S)!=0){
					visible(g1_1)<-FALSE
					l$Series_Matrix$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
			if(length(which(x=="Online_Data"))!=0){
				er_x<-try(use_DE_O<<-DE_O,silent=TRUE)
				if(length(grep("Error",er_x))!=0)
				{
					rownames(DE_O)<<-as.character(DE_O)
					use_DE_O<<-DE_O
				}
				err_x<-try(Clas_O<<-use.data.matrix_onlineNorm.m[rownames(use_DE_O),samp_O],silent=TRUE)
				if(length(grep("Error",err_x))!=0)
				{
					Clas_O<<-use.data.matrix_onlineNorm.m[use_DE_O$ID,]
				}
				heatmap(Clas_O,margins=c(7,7),Rowv=NA,Colv=NA,cexCol=0.8,cexRow=0.8,col=heatcol)
				if(length(Clas_O)!=0){
					visible(g1_1)<-FALSE
					l$Online_Data$Classification<<-list()
					tr<<-gtree(offspring=tree,container=g1_1)
					size(tr)<-c(300,400)
					visible(g1_1)<-TRUE
				}
				display()
			}
		svalue(sb)<-"Done"
		dispose(w_dge)
		}else{
			gmessage("Plz select the data for Classification","Select Data")
		}
		svalue(sb)<-"Done"
		dispose(w_dge)
	},container=gp2_dge,anchor=c(1,-1))
	visible(w_dge)<-TRUE
}
